@@ -6,12 +6,10 @@ from werkzeug.serving import run_simple
 from werkzeug.wrappers import Request, Response
 from werkzeug.exceptions import HTTPException, NotFound
 from werkzeug.routing import Map, Rule
-from ashes import AshesEnv
-
+from mako.lookup import TemplateLookup
 
 apiname = os.environ.get('SOLACE_API_NAME', str(uuid.uuid4()))
 
-# TODO: catch any errors that may come from not passing the proper data type here
 # TODO: raise our own custom error types
 def objectify(dict):
     return munch.munchify(dict)
@@ -23,10 +21,14 @@ class SolaceResponse(Response):
     def __init__(self, config = {}):
         super().__init__()
         self.config = config
-        self.tplenv = AshesEnv([self.config.get("templates_dir", "src/templates")])
+        self.lookup = TemplateLookup(
+            directories=[self.config.get("templates_dir", "src/templates")], 
+            module_directory=self.config.get("modules_dir", "src/modules")
+        )
 
     def tpl(self, template, context = {}):
-        self.html = self.tplenv.render(template, context)
+        template = self.lookup.get_template(template)
+        self.html = template.render(**context)
 
 class Solace:
     
